@@ -4,7 +4,7 @@ from .user_address import UserAddress
 from .base import BaseModelAbstract
 from .user import User
 from .work_order_service import WorkOrderServiceCategory
-from .payment import PaymentType, PaymentVendor
+from .payment import PaymentVendor
 
 
 class WorkOrder(BaseModelAbstract, models.Model):
@@ -15,8 +15,8 @@ class WorkOrder(BaseModelAbstract, models.Model):
                                 null=True)
     agent = models.ForeignKey(User, models.SET_NULL, blank=True, null=True, 
                               related_name="workorders_agent_set")
-    paymentType = models.ForeignKey(PaymentType, models.SET_NULL, null=True,
-                                    blank=True)
+    # paymentType = models.ForeignKey(PaymentType, models.SET_NULL, null=True,
+    #                                 blank=True)
     paymentVendor = models.ForeignKey(PaymentVendor, models.SET_NULL, 
                                       null=True, blank=True)
     description = models.TextField(blank=True, null=True)
